OC.L10N.register(
    "calendar",
    {
    "Calendar" : "달력",
    "Individual" : "개별",
    "Group" : "그룹",
    "Resource" : "자원",
    "Room" : "방",
    "Unknown" : "알 수 없음",
    "Required" : "필요함",
    "Optional" : "선택적",
    "Does not attend" : "참석하지 않음",
    "New event" : "새 일정",
    "Attendees" : "참석자",
    "Reminders" : "알림",
    "Repeating" : "반복",
    "When shared show full event" : "전체 일정 공유",
    "When shared show only busy" : "바쁨/한가함만 공유",
    "When shared hide this event" : "일정 공유하지 않음",
    "Global" : "전역",
    "None" : "없음",
    "never" : "없음",
    "At time of event" : "일정 정각",
    "5 minutes before" : "5분 전",
    "10 minutes before" : "10분 전",
    "15 minutes before" : "15분 전",
    "30 minutes before" : "30분 전",
    "1 hour before" : "1시간 전",
    "2 hours before" : "2시간 전",
    "Custom" : "사용자 정의",
    "Audio" : "오디오",
    "E Mail" : "이메일",
    "Pop up" : "팝업",
    "sec" : "초",
    "min" : "분",
    "hours" : "시간",
    "days" : "일",
    "week" : "주",
    "Week {number} of {year}" : "{year}년 제 {number}주",
    "Successfully imported" : "성공적으로 가져옴",
    "Partially imported, 1 failure" : "일부만 가져옴, 1개 항목 실패",
    "Partially imported, {n} failures" : "일부만 가져옴, {n}개 항목 실패",
    "Audio alarm" : "오디오 알람",
    "Pop-up" : "팝업",
    "E-Mail" : "이메일",
    "{type} {time} before the event starts" : "일정 시작 {time} 전 {type}",
    "{type} {time} before the event ends" : "일정 종료 {time} 전 {type}",
    "{type} {time} after the event starts" : "일정 시작 {time} 후 {type}",
    "{type} {time} after the event ends" : "일정 종료 {time} 후 {type}",
    "{type} at the event's start" : "일정 시작 시 {type}",
    "{type} at the event's end" : "일정 종료 시 {type}",
    "{type} at {time}" : "{time}에 {type}",
    "{calendar} shared by {owner}" : "{owner} 님이 공유한 달력",
    "Title of the Event" : "일정 제목",
    "starts" : "시작",
    "ends" : "끝",
    "All day Event" : "종일 일정",
    "Location" : "위치",
    "Delete" : "삭제",
    "Cancel" : "취소",
    "More ..." : "더 보기...",
    "Create" : "만들기",
    "Update" : "업데이트",
    "Close" : "닫기",
    "Description" : "설명",
    "Export" : "내보내기",
    "Day" : "일",
    "Week" : "주",
    "Month" : "달",
    "Today" : "오늘",
    "Share Calendar" : "달력 공유",
    "More" : "더 보기",
    "Edit" : "편집",
    "group" : "그룹",
    "New Calendar" : "새 달력",
    "Subscriptions" : "구독",
    "New Subscription" : "새 구독",
    "Url" : "URL",
    "Edit event" : "일정 편집",
    "Delete Event" : "일정 삭제",
    "Save Event" : "일정 저장",
    "Time" : "시간",
    "Type" : "종류",
    "Relative" : "상대적",
    "Absolute" : "절대적",
    "Repeat" : "반복",
    "Add" : "추가",
    "Please add your email address in the personal settings in order to add attendees." : "참석자 목록을 편집하려면 개인 설정에서 이메일 주소를 추가하십시오.",
    "from" : "시작",
    "to" : "끝",
    "Import Calendars" : "달력 가져오기",
    "Import canceled" : "가져오기 취소됨",
    "Analyzing calendar" : "달력 분석 중",
    "The file contains objects incompatible with the selected calendar" : "이 파일에 현재 달력과 호환되지 않는 객체가 들어 있습니다",
    "New calendar" : "새 달력",
    "Import scheduled" : "가져오기 예약됨",
    "Settings" : "설정",
    "Import calendar" : "달력 가져오기",
    "No Calendars selected for import" : "가져올 달력을 선택하지 않았음",
    "Primary CalDAV address" : "주 CalDAV 주소",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV 주소"
},
"nplurals=1; plural=0;");
